#Read.me ----
#This file produces figure S7 in the supplementary files which belong to the Scenario-1
#February,2022
#---------------------------------------------------------------------------------------------------------   
#Clean workspace and Load Libraries ----
  rm(list = ls()) #Removes workspace data
  library(pacman)
  pacman::p_load("grDevices","utils","pacman","ggplot2","gridExtra","data.table","dplyr","ggpubr",install = FALSE)
#---------------------------------------------------------------------------------------------------------   
#Parameters and Path to data folder  ----
  # main_data_folder='The path to Tables'
  # output_folder='The path to output folder where figures will be saved'
  setwd(main_data_folder);
#---------------------------------------------------------------------------------------------------------   
#Read data ----
  #Counts of CB+CC in each of three clones in GC in each of 30 repeats
  Clones.population.in.GC<-read.table(paste(main_data_folder,"Clones_Population_in_GC.csv",sep=""),header=TRUE,sep=",")
  #Average/Min/Max of Affinity and collected Ags of non-apoptotic B cells in three clones in GC. average over 30 repeats
  Clones.time.summary<-read.table(paste(main_data_folder,"Clones_Temporal_Ag_Affinity_summary.csv",sep=""),header=TRUE,sep=",")
  #Output cells counts per clone, in each of 30 repeats
  OCs.counts<-read.table(paste(main_data_folder,"OC_counts.csv",sep=""),header=TRUE,sep=",")
  #Average/Min/Max of affinity of OCs per clone in time in 30 repeats 
  OCs.temporal.affinity.summary<-read.table(paste(main_data_folder,"OCs_Temporal_Affinity_summary.csv",sep=""),header=TRUE,sep=",")
  #Affinity of three clones in time in each of 30 repeats
  Clones.Affinity.Repeats<-read.table(paste(main_data_folder,"Clones_Affinity_repeats.csv",sep=""),header=TRUE,sep=",")
  #Frequency of events (CC-FDC interaction, Bindings, dissociation with and without Ag) for non-apoptotic CCs entering Tfh cell selection phase in all of 30 repeats
  CC.ACP.events<-read.table(paste(main_data_folder,"CC_ACP_events.csv",sep=""),header=TRUE,sep=",")
#---------------------------------------------------------------------------------------------------------   
#Plot configs ----
  #This will make a file that is 'pwidth' x 'pheight' pixels, with an 'pres' dpi
  pwidth=6.5
  pheight=5.5
  punits="cm"
  psize=12
  pres=600 #dpi
  
  #Colors for different types of clones:
  #1 =Clone-M
  colors.clones<- c("1"= "#9442F0")
  colors.clones.light<-c("1"= "#AA75E4");
  labels.clones<- c("1"="Clone-M")
  
  #Themes:
  # Publication theme
  theme.pub<-theme(axis.text=element_text(size=8,face="bold",family="serif",color="black"),
                   axis.title=element_text(size=10,face="bold",family="serif",color="black"),
                   title = element_text(size=12,face="bold",family="serif",color="black"),
                   plot.background = element_blank(),panel.grid.major = element_blank(), 
                   panel.grid.minor = element_blank(), panel.background = element_blank(),
                   axis.line = element_line(colour = "black"),
                   axis.title.y = element_text(size=10,face="bold",family="serif",color="black",margin =margin(t = 0, r = -.2, b = 0, l = 0.2),angle = 90),
                   legend.margin = margin(r = -1.0, unit='mm'),
                   legend.text=element_text(size=8,face="bold",family="serif",color="black"),legend.title = element_text(size=8,color="black",face="bold",family="serif"),
                   panel.border = element_rect(colour = "black", fill=NA, size=1),
                   legend.justification='left',legend.direction='horizontal',legend.key = element_rect(colour = "white", fill = NA),
                   legend.spacing.x = unit(1, 'pt'),legend.key.size = unit(8, 'pt'),legend.spacing.y = unit(1, 'pt'),legend.background = element_rect(fill="transparent",color="transparent"));
  
  theme.facet.pub<-theme(axis.text= element_text(size=8,face="bold",family="serif",color="black"),
                         axis.title=element_text(size=10,face="bold",family="serif",color="black"),                       plot.background = element_blank(),panel.grid.major = element_blank(), 
                         panel.grid.minor = element_blank(),panel.background = element_blank(),
                         axis.line = element_line(colour = "black"),axis.title.y = element_text(size=10,face="bold",family="serif",color="black",margin =margin(t = 0, r = -.2, b = 0, l = 0.2),angle = 90),
                         legend.margin = margin(r = -0.5, unit='mm'),legend.text=element_text(size=8,face="bold",family="serif",color="black"),
                         legend.title = element_text(size=8,color="black",face="bold",family="serif"));
  #Linetypes
  linetypes3<-c("GC"="longdash","Output"="solid")
#---------------------------------------------------------------------------------------------------------   
#A) Clones population dynamics in GC in time ----
  #This includes counts of CB+CC
  fig1a<-Clones.population.in.GC%>%subset(!is.na(Total))%>%group_by(time,Clone_ID)%>%dplyr::summarise(mean=mean(Total,na.rm=TRUE))%>%ggplot()+
    geom_line(aes(x=time,y=mean,color=as.factor(Clone_ID),group=Clone_ID),size=1)+
    guides(color=guide_legend(""))+
    scale_color_manual(values=colors.clones,labels=c("Clone-M"))+
    labs(y="CB+CC count",x="Time (h)",title="A")+
    theme.pub+theme(legend.position=c(.7,0.85),legend.direction = "vertical")+
    ylim(0,4000)
  
  file_name = paste(output_folder,"SCS_1_A.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1a)  
  invisible(dev.off())

#C) Picked up Ag by each clone in GC in time ----
  fig1b <-ggplot(data=subset(Clones.time.summary,!is.na(Clone_Ag_mean)),aes(group=Clone_ID))+
    geom_ribbon(aes(time, ymin=Clone_Ag_min, ymax=Clone_Ag_max,color=as.factor(Clone_ID),fill=as.factor(Clone_ID)),size=0,alpha=0.2)+
    geom_line(aes(time,Clone_Ag_mean,color=as.factor(Clone_ID)),size=1)+
    scale_color_manual(values = colors.clones,labels=c("Clone-M"))+scale_fill_manual(values=colors.clones.light,labels=c("Clone-M"))+
    guides(color="none",fill=guide_legend("",order=1,override.aes = list(fill=colors.clones.light,alpha=0.6,size=0.1)))+
    labs(title="C",x="Time (h)",y="Clone Ag")+ylim(0,10000)+
    theme.pub+theme(legend.position = c(0.7,0.85),legend.direction = "vertical")

  file_name = paste(output_folder,"SCS_1_B.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1b)  
  invisible(dev.off())
#D) Events boxplots for CCs entering Tfh selection phase ----
  #Order of appearance of categorical data on x axis 
  level_order <- c('FDC_interactions', 'Associations', 'Dissociations_WO_Ag','Dissociations_W_Ag');
  fig1c<-ggplot(CC.ACP.events, aes(x = factor(variable,level = level_order), y = value,color = as.factor(Clone_ID)))+
     geom_boxplot(outlier.size = .5)+labs(title="D",x="",y="Frequency")+
     scale_color_manual(values=colors.clones,labels=c("1"="Clone-M"))+
     theme.pub+theme(axis.title.y = element_text(margin=margin(r=0,l=-1,b=0,t=0)),plot.title =  element_text(margin=margin(r=0,l=0,b=-1,t=4)),plot.margin = margin(l=2,r=20,t=-2,b=-8),axis.text.x = element_text(size=8,face="bold",family="serif",color="black",angle=45,margin=margin(t=12,b=-20,l=0,r=0)),legend.position=c(.7,0.85),legend.direction = "vertical")+
     scale_x_discrete(labels = c('CC-FDC \ninteractions','Associations','Dissociations\nwithout Ag','Dissociations\nwith Ag'))+
     guides(color=guide_legend(""))+stat_summary(fun.y=mean, aes(group=Clone_ID),color="black",geom="point", size=.5,position=position_dodge(0.71))
  
  file_name = paste(output_folder,"SCS_1_C.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1c)  
  invisible(dev.off())
  
#B) Population of positively selected CCs ----
  fig1d<- Clones.population.in.GC%>%group_by(time,Clone_ID)%>%dplyr::summarise(mean=mean(TC_Selected))%>%ggplot()+geom_line(aes(time,mean,color=as.factor(Clone_ID)),size=1)+
    labs(y="Positively selected CCs",x="Time (h)",title="B",subtitle="")+theme.pub+guides(color=guide_legend(""))+scale_color_manual(values=colors.clones,labels=c("Clone-M"))+ylim(0,1000)+theme(plot.title=element_text(margin=margin(r=0,t=0,b=-13,l=2)),legend.position = c(0.7,0.85),legend.direction = "vertical")
  file_name = paste(output_folder,"SCS_1_D.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1d)  
  invisible(dev.off())
  
#F) Produced output cells from each clone ----
  mean.OCs.per.clone<-OCs.counts%>%group_by(Clone_ID)%>%dplyr::summarise(mean=mean(count));
  fig2a<-ggplot(OCs.counts)+
    geom_count(aes(x=(Clone_ID),y=count),size=2,position=position_jitter(width = 0.35,height = 0, seed=10))+
    geom_segment(data=mean.OCs.per.clone,aes(x = Clone_ID-.1, y = mean, xend = Clone_ID+.1, yend = mean,linetype="Average"),color="red",size=1)+
    guides(color="none",linetype="none")+scale_linetype_manual(name="",label="",values=c("Average"="solid"))+
    labs(title="F",y="Output cell count",x="")+
    theme.pub+
    ylim(0,20000)+theme(legend.position=c(.05,0.85))+
    xlim("Clone-M")

  file_name = paste(output_folder,"SCS_2_A.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig2a)  
  invisible(dev.off())
  
#E) Affinity of OCs and GC B cells in three clones ---- 
fig2b<-ggplot()+
    geom_ribbon(data=OCs.temporal.affinity.summary,aes(time,ymin=Clone_M_Affinity_min,ymax=Clone_M_Affinity_max,fill="1"),alpha=0.05)+  
  geom_line(data=subset(Clones.time.summary,!is.na(Affinity_mean)),aes(time,Affinity_mean,color=as.factor(Clone_ID),linetype="GC"))+
  geom_line(data=OCs.temporal.affinity.summary,aes(time,Clone_M_Affinity_mean,color="1",linetype="Output"))+
  scale_color_manual(values = colors.clones,labels=c("Clone-M"))+
  scale_fill_manual(values = colors.clones,labels=c("Clone-M"))+
  scale_linetype_manual(name="",values = linetypes3)+
  guides(color=guide_legend("",order=1,override.aes=list(fill=NA)),fill="none",linetype="none")+
  labs(title="E",y="Affinity",x="Time (h)")+
  theme.pub+theme(legend.position = c(0.7,0.05),legend.direction = "vertical",legend.box.margin = margin(l=0,r=0,t=-15,b=5),legend.spacing.y = unit(-4,"pt") )+
  scale_y_continuous(limits=c(0,1),breaks=seq(0,1,0.1))
  
  file_name = paste(output_folder,"SCS_2_B.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig2b)  
  invisible(dev.off())
#--------------------------------------------------------------------------------------------------------- 
