#Read.me ----
#This file produces figures in the manuscript and supplementary files which belong to the Reference Scenario
#This include Figs 3I-L, 4C and 4F, S3 and S6
#Last Update: September,2021
#---------------------------------------------------------------------------------------------------------   
#Clean workspace and Load Libraries ----
  rm(list = ls()) #Removes workspace data
  library(pacman)
  pacman::p_load("grDevices","utils","pacman","ggplot2","gridExtra","data.table","dplyr","ggpubr",install = FALSE)
#---------------------------------------------------------------------------------------------------------   
#Parameters and Path to data folder  ----
  main_data_folder='The path to Tables'
  output_folder='The path to output folder where figures will be saved'  
  setwd(main_data_folder);
#---------------------------------------------------------------------------------------------------------   
#Read data ----
  
  #Counts of CB+CC in each of three clones in GC in each of 30 repeats
  Clones.population.in.GC<-read.table(paste(main_data_folder,"Clones_Population_in_GC.csv",sep=""),header=TRUE,sep=",")
  #Average/Min/Max of Affinity and collected Ags of non-apoptotic B cells in three clones in GC, average over 30 repeats
  Clones.time.summary<-read.table(paste(main_data_folder,"Clones_Temporal_Ag_Affinity_summary.csv",sep=""),header=TRUE,sep=",")
  #Output cells counts per clone, in each of 30 repeats
  OCs.counts<-read.table(paste(main_data_folder,"OC_counts.csv",sep=""),header=TRUE,sep=",")
  #Average/Min/Max of affinity of OCs per clone in time, average of 30 repeats 
  OCs.temporal.affinity.summary<-read.table(paste(main_data_folder,"OCs_Temporal_Affinity_summary.csv",sep=""),header=TRUE,sep=",")
  #Affinity of three clones in time in each of 30 repeats
  Clones.Affinity.Repeats<-read.table(paste(main_data_folder,"Clones_Affinity_repeats.csv",sep=""),header=TRUE,sep=",")
  #Frequency of events (CC-FDC interaction, Bindings, dissociation with and without Ag) for non-apoptotic CCs entering Tfh cell selection phase in all of 30 repeats
  CC.ACP.events<-read.table(paste(main_data_folder,"CC_ACP_events.csv",sep=""),header=TRUE,sep=",")
  
#---------------------------------------------------------------------------------------------------------   
#Plot configs ----
  #This will make a file that is 'pwidth' x 'pheight' pixels, with an 'pres' dpi
  pwidth=748
  pheight=655
  punits="px"
  psize=12
  pres=300 #dpi
  
  #Colors for different types of clones:
  #1 =Clone-L, 2=Clone-M, 3=Clone-H
  colors.clones<- c("1"= "red","2"= "#009ADE","3"= "#00BB00")
  colors.clones.light<-c("1"= "#f7c1ce","2"= "#9EC9E2","3"= "#9CCEA7");
  labels.clones<- c("1"="Clone-L","2"= "Clone-M","3"= "Clone-H")
  
  #Themes:
  # Publication theme
  theme.pub<-theme(axis.text=element_text(size=8,face="bold",family="serif",color="black"),
                   axis.title=element_text(size=10,face="bold",family="serif",color="black"),
                   title = element_text(size=12,face="bold",family="serif",color="black"),
                   plot.background = element_blank(),panel.grid.major = element_blank(), 
                   panel.grid.minor = element_blank(), panel.background = element_blank(),
                   axis.line = element_line(colour = "black"),
                   axis.title.y = element_text(size=10,face="bold",family="serif",color="black",margin =margin(t = 0, r = -.2, b = 0, l = 0.2),angle = 90),
                   legend.margin = margin(r = -1.0, unit='mm'),
                   legend.text=element_text(size=8,face="bold",family="serif",color="black"),legend.title = element_text(size=8,color="black",face="bold",family="serif"),
                   panel.border = element_rect(colour = "black", fill=NA, size=1),
                   legend.justification='left',legend.direction='horizontal',legend.key = element_rect(colour = "white", fill = NA),
                   legend.spacing.x = unit(1, 'pt'),legend.key.size = unit(8, 'pt'),legend.spacing.y = unit(1, 'pt'),legend.background = element_rect(fill="transparent",color="transparent"));
  
  theme.facet.pub<-theme(axis.text= element_text(size=8,face="bold",family="serif",color="black"),
                         axis.title=element_text(size=10,face="bold",family="serif",color="black"),                       plot.background = element_blank(),panel.grid.major = element_blank(), 
                         panel.grid.minor = element_blank(),panel.background = element_blank(),
                         axis.line = element_line(colour = "black"),axis.title.y = element_text(size=10,face="bold",family="serif",color="black",margin =margin(t = 0, r = -.2, b = 0, l = 0.2),angle = 90),
                         legend.margin = margin(r = -0.5, unit='mm'),legend.text=element_text(size=8,face="bold",family="serif",color="black"),
                         legend.title = element_text(size=8,color="black",face="bold",family="serif"));
  #Linetypes
  linetypes3<-c("GC"="longdash","Output"="solid")
#---------------------------------------------------------------------------------------------------------   
#Fig1 (3I-3L in manuscript) ----
#a) Clones population dynamics in GC in time ----
  #This includes counts of CB+CC
  fig1a<-Clones.population.in.GC%>%subset(!is.na(Total))%>%group_by(time,Clone_ID)%>%dplyr::summarise(mean=mean(Total,na.rm=TRUE))%>%ggplot()+
    geom_line(aes(x=time,y=mean,color=as.factor(Clone_ID),group=Clone_ID),size=1)+
    guides(color=guide_legend(""))+
    scale_color_manual(values=colors.clones,labels=c("Clone-L","Clone-M","Clone-H"))+
    labs(y="CB+CC count",x="Time (h)",title="I")+
    theme.pub+theme(legend.position=c(.7,0.85),legend.direction = "vertical")+
    ylim(0,2000)
  
  file_name = paste(output_folder,"SC2_1_A.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1a)  
  invisible(dev.off())
#b) Picked up Ag by each clone in GC in time ----
  fig1b <-ggplot(Clones.time.summary,aes(group=Clone_ID))+
    geom_ribbon(aes(time, ymin=Clone_Ag_min, ymax=Clone_Ag_max,color=as.factor(Clone_ID),fill=as.factor(Clone_ID)),size=0,alpha=0.2)+
    geom_line(aes(time,Clone_Ag_mean,color=as.factor(Clone_ID)),size=1)+
    scale_color_manual(values = colors.clones,labels=c("Clone-L","Clone-M","Clone-H"))+scale_fill_manual(values=colors.clones.light,labels=c("Clone-L","Clone-M","Clone-H"))+
    guides(color="none",fill=guide_legend("",order=1,override.aes = list(fill=colors.clones.light,alpha=0.6,size=0.1)))+
    labs(title="J",x="Time (h)",y="Clone Ag")+ylim(0,6000)+
    theme.pub+theme(legend.position = c(0.7,0.85),legend.direction = "vertical")
  
  file_name = paste(output_folder,"SC2_1_B.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1b)  
  invisible(dev.off())
#c) Events boxplots for CCs entering Tfh selection phase ----
  #Order of appearance of categorical data on x axis 
  level_order <- c('FDC_interactions', 'Associations', 'Dissociations_WO_Ag','Dissociations_W_Ag');
  fig1c<-ggplot(CC.ACP.events, aes(x = factor(variable,level = level_order), y = value,color = as.factor(Clone_ID)))+
    geom_boxplot(outlier.size = .5)+labs(title="K",x="",y="Frequency")+scale_color_manual(values=colors.clones,labels=c("1"="Clone-L","2"="Clone-M","3"="Clone-H"))+
    theme.pub+theme(axis.title.y = element_text(margin=margin(r=0,l=-1,b=0,t=0)),plot.title =  element_text(margin=margin(r=0,l=0,b=-1,t=4)),plot.margin = margin(l=2,r=20,t=-2,b=-8),axis.text.x = element_text(size=8,face="bold",family="serif",color="black",angle=45,margin=margin(t=12,b=-20,l=0,r=0)),legend.position=c(.7,0.85),legend.direction = "vertical")+
    scale_x_discrete(labels = c('CC-FDC \ninteractions','Associations','Dissociations\nwithout Ag','Dissociations\nwith Ag'))+
    guides(color=guide_legend(""))+stat_summary(fun.y=mean, aes(group=Clone_ID),color="black",geom="point", size=.5,position=position_dodge(0.71))
  
  
  file_name = paste(output_folder,"SC2_1_C.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1c)  
  invisible(dev.off())

  #d) Population of positively selected CCs ----
  fig1d<- Clones.population.in.GC%>%group_by(time,Clone_ID)%>%dplyr::summarise(mean=mean(TC_Selected))%>%ggplot()+geom_line(aes(time,mean,color=as.factor(Clone_ID)),size=1)+
    labs(y="Positively selected CCs",x="Time (h)",title="L",subtitle="")+theme.pub+guides(color=guide_legend(""))+scale_color_manual(values=colors.clones,labels=c("Clone-L","Clone-M","Clone-H"))+ylim(0,1000)+theme(plot.title=element_text(margin=margin(r=0,t=0,b=-13,l=2)),legend.position = c(0.7,0.85),legend.direction = "vertical")
  
  file_name = paste(output_folder,"SC2_1_D.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig1d)  
  invisible(dev.off())
  
#---------------------------------------------------------------------------------------------------------   
#Fig 2 (4C and 4F in manuscript) ----
#a) Produced output cells from each clone ----
  mean.OCs.per.clone<-OCs.counts%>%group_by(Clone_ID)%>%dplyr::summarise(mean=mean(count));
  fig2a<-ggplot(OCs.counts)+
    geom_count(aes(x=(Clone_ID),y=count),size=2,position=position_jitter(width = 0.25,height = 0, seed=10))+
    geom_segment(data=mean.OCs.per.clone,aes(x = Clone_ID-.1, y = mean, xend = Clone_ID+.1, yend = mean,linetype="Average"),color="red",size=1)+
    guides(color="none",linetype="none")+scale_linetype_manual(name="",label="",values=c("Average"="solid"))+
    labs(title="E",y="Output cell count",x="")+
    theme.pub+
    ylim(0,11500)+theme(legend.position=c(.05,0.85))+
    xlim("Clone-L","Clone-M","Clone-H")
 
   file_name = paste(output_folder,"SC2_2_A.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig2a)  
  invisible(dev.off())
  
#b) Affinity of OCs and GC B cells in three clones ---- 
  fig2b<-ggplot()+
    geom_ribbon(data=OCs.temporal.affinity.summary,aes(time,ymin=Clone_L_Affinity_min,ymax=Clone_L_Affinity_max,fill="1"),alpha=0.05)+  
    geom_ribbon(data=OCs.temporal.affinity.summary,aes(time,ymin=Clone_M_Affinity_min,ymax=Clone_M_Affinity_max,fill="2"),alpha=0.05)+  
    geom_ribbon(data=OCs.temporal.affinity.summary,aes(time,ymin=Clone_H_Affinity_min,ymax=Clone_H_Affinity_max,fill="3"),alpha=0.05)+  
    geom_line(data=subset(Clones.time.summary,!is.na(Affinity_mean)),aes(time,Affinity_mean,color=as.factor(Clone_ID),linetype="GC"))+
    geom_line(data=OCs.temporal.affinity.summary,aes(time,Clone_L_Affinity_mean,color="1",linetype="Output"))+
    geom_line(data=OCs.temporal.affinity.summary,aes(time,Clone_M_Affinity_mean,color="2",linetype="Output"))+
    geom_line(data=OCs.temporal.affinity.summary,aes(time,Clone_H_Affinity_mean,color="3",linetype="Output"))+
    scale_color_manual(values = colors.clones,labels=c("Clone-L","Clone-M","Clone-H"))+
    scale_fill_manual(values = colors.clones,labels=c("Clone-L","Clone-M","Clone-H"))+
    scale_linetype_manual(name="",values = linetypes3)+
    guides(fill="none",color=guide_legend("",order=1,override.aes=list(fill=NA)),linetype="none")+
    labs(title="F",y="Affinity",x="Time (h)")+
    theme.pub+theme(legend.position = c(0.7,0.05),legend.direction = "vertical",legend.box.margin = margin(l=0,r=0,t=-15,b=5),legend.spacing.y = unit(-4,"pt") )+
    scale_y_continuous(limits=c(0,1),breaks=seq(0,1,0.1))

  file_name = paste(output_folder,"SC2_2_B.tif",sep='')
  tiff(filename = file_name, res=pres,width = pwidth, height = pheight, units = punits, pointsize = psize)
  grid.arrange(fig2b)  
  invisible(dev.off())
  

#---------------------------------------------------------------------------------------------------------   
#Fig S3 in manuscript, clone population in 30 simulations ----

  figS1<-ggplot(subset(Clones.population.in.GC,!is.na(Total)))+
    geom_line(aes(x=time,y=Total,group=Clone_ID,color=as.factor(Clone_ID)))+
    guides(color=guide_legend(""))+
    scale_color_manual(name="",labels=labels.clones,values = colors.clones)+
    labs(y="CB+CC count",x="Time (h)")+
    theme.facet.pub+
    ylim(0,2000)+
    facet_wrap(~facet_ID)+theme(legend.position="top",panel.spacing.x = unit(10,"pt"),axis.text.x =element_text(size=8,face="bold",family="serif",color="black") )
  file_name = paste(output_folder,"Scenario_A_Fig_S1.tif",sep='')
  tiff(filename =file_name , res=pres,width = 2250, height = 2250, units = punits, pointsize = psize)
  print(figS1)
  invisible(dev.off())

#---------------------------------------------------------------------------------------------------------   
#Fig S6 in manuscript, clone affinity in 30 simulations  ----
  figS2<-ggplot(data=subset(Clones.Affinity.Repeats,!is.na(Affinity_avg)))+
    geom_line(aes(x=time,y=Affinity_avg,group=Clone_ID,color=as.factor(Clone_ID)))+
    guides(color=guide_legend(""))+
    scale_color_manual(name="",labels=labels.clones,values = colors.clones)+
    labs(y="Affinity",x="Time (h)")+
    theme.facet.pub+ylim(0,1)+
    facet_wrap(~facet_ID)+theme(legend.position="top",panel.spacing.x = unit(10,"pt"),axis.text.x =element_text(size=8,face="bold",family="serif",color="black") )
  file_name = paste(output_folder,"Scenario_A_Fig_S2.tif",sep='')
  tiff(filename =file_name , res=pres,width = 2250, height = 2250, units = punits, pointsize = psize)
  print(figS2)
  invisible(dev.off())

#---------------------------------------------------------------------------------------------------------   
