#This file produces Fig 5B in manuscript that shows correlation between Pa,Pd and Affinity 
#September, 2021
#-----------------------------
#Clean workspace and Load Libraries ----
  rm(list = ls()) #Removes workspace data
  library(pacman)
  pacman::p_load("grDevices","utils","pacman","ggplot2","gridExtra","data.table","dplyr","ggpubr",install = FALSE)
  
#Plot configs ----
#This will make a file that is 2500 x 2500 pixels, with an 300 dpi
pwidth=2500
pheight=2500
punits="px"
psize=12
pres=300 #dpi

#Themes:
# Publication theme
theme.pub<-theme(axis.text=element_text(size=12,face="bold",family="serif",color="black"),
                 axis.title=element_text(size=12,face="bold",family="serif",color="black"),
                 title = element_text(size=12,face="bold",family="serif",color="black"),
                 plot.background = element_blank(),panel.grid.major = element_blank(), 
                 panel.grid.minor = element_blank(), panel.background = element_blank(),
                 axis.line = element_line(colour = "black"),
                 axis.title.y = element_text(size=12,face="bold",family="serif",color="black",margin =margin(t = 0, r = -.2, b = 0, l = 0.2),angle = 90),
                 legend.margin = margin(r = -1.0, unit='mm'),
                 legend.text=element_text(margin(t = -1, unit='cm'),size=11,face="bold",family="serif",color="black"),legend.title = element_text(size=10,color="black",face="bold",family="serif"),
                 panel.border = element_rect(colour = "black", fill=NA, size=1),
                 legend.justification='left',legend.direction='horizontal',legend.key = element_rect(colour = "white", fill = NA),
                 legend.spacing.x = unit(-.01, 'cm'),legend.spacing.y = unit(.0 , 'cm'),legend.background = element_rect(fill="transparent",color="transparent"),legend.key.size = unit(0.35,"cm"));

#Costum color set  
tcol<-c("#931605","#EA280C","#A70D71","#E817A9","#350D93","#4283EF","#057A17","#09BB25","#72F511","#FE7C06")
#-----------------------------
output_folder='The path to output folder where the figure will be saved'
#Distance of Ab to Ag in shape-space
d<-seq(0,10,1);
#Affinity according to distance
affinity<-exp(-1*d^2/2.8^2)
#Theta
theta<-seq(0,90,5);
i<-0;
#Pa,Pd matrix
Prob<-data.frame(matrix(ncol = 4, nrow = length(theta)*length(d)))
x<-c( "d","th","Pa", "Pd")
colnames(Prob)<-x
k<-0;

for (i in seq(1,length(theta)))
{
 for (j in seq(1,length(d)))
 {
   k<-k+1;
   Prob$th[k]<-theta[i];
   Prob$d[k]<-d[j];
   Prob$Pa[k]<-exp((-1*d[j]^2*sin(theta[i]*pi/180)^2)/(2.8^2))
   Prob$Pd[k]<-1-exp((-1*d[j]^2*cos(theta[i]*pi/180)^2)/(2.8^2))
   Prob$Affinity[k]<-exp((-1*d[j]^2/(2.8^2)))
 }
}
fig<-ggplot(Prob)+geom_line(aes(x=Pd,y=Pa,color=as.factor(th),group=th))+
  geom_point(aes(x=Pd,y=Pa,fill=as.factor(round(Affinity, digits = 4))),size=2.5,shape=21)+
  guides(color=guide_legend(expression(theta),ncol=1),fill=guide_legend(title=element_text( "Affinity"),order=1))+
  theme.pub+theme(legend.box="vertical" ,legend.direction = "vertical",legend.position=c(0.87,0.51))+
  scale_x_continuous(breaks = c(0,.25,.5,.75,1.0),limits = c(0,1.15))+
  scale_fill_manual(values = tcol)
file_name = paste(output_folder,"Pa_Pd_theta_Affinity.tiff",sep='')
tiff(filename = file_name, res=pres,width = 1600, height = 1600, units = punits, pointsize = psize)
ggarrange(fig)
invisible(dev.off())